@@ -3,7 +3,7 @@ package HTML::FormFu::Constraint::Length;
 use strict;
 use base 'HTML::FormFu::Constraint';
 
-__PACKAGE__->mk_item_accessors( qw( minimum maximum ) );
+__PACKAGE__->mk_item_accessors(qw( minimum maximum ));
 
 *min = \&minimum;
 *max = \&maximum;
@@ -13,17 +13,23 @@ sub constrain_value {
 
     return 1 if !defined $value || $value eq '';
 
-    if ( defined ( my $min = $self->minimum ) ) {
+    if ( defined( my $min = $self->minimum ) ) {
         return 0 if length $value < $min;
     }
 
-    if ( defined ( my $max = $self->maximum ) ) {
+    if ( defined( my $max = $self->maximum ) ) {
         return 0 if length $value > $max;
     }
 
     return 1;
 }
 
+sub _localize_args {
+    my ($self) = @_;
+
+    return $self->min, $self->max;
+}
+
 1;
 
 __END__
