@@ -4,22 +4,23 @@ use strict;
 use base 'HTML::FormFu::Element';
 use Class::C3;
 
-use HTML::FormFu::Attribute qw/ mk_output_accessors /;
-use HTML::FormFu::ObjectUtil qw/ :FORM_AND_BLOCK /;
-use HTML::FormFu::Util qw/ _get_elements xml_escape process_attrs /;
+use HTML::FormFu::ObjectUtil qw( :FORM_AND_BLOCK );
+use HTML::FormFu::Util qw( _get_elements xml_escape process_attrs );
+use List::MoreUtils qw( uniq );
 use Storable qw( dclone );
-use Carp qw/croak/;
+use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw/ tag _elements nested_name /);
+__PACKAGE__->mk_item_accessors(qw( tag _elements nested_name ));
 
-__PACKAGE__->mk_output_accessors(qw/ content /);
+__PACKAGE__->mk_output_accessors(qw( content ));
 
-__PACKAGE__->mk_inherited_accessors(
-    qw/ auto_id auto_label auto_error_class auto_error_message
+__PACKAGE__->mk_inherited_accessors( qw(
+        auto_id auto_label auto_error_class auto_error_message
         auto_constraint_class auto_inflator_class auto_validator_class
         auto_transformer_class render_processed_value force_errors
-        repeatable_count /
-);
+        repeatable_count
+        locale
+) );
 
 *elements     = \&element;
 *constraints  = \&constraint;
@@ -58,9 +59,11 @@ sub _single_plugin {
     my @names = map { ref $_ ? @$_ : $_ }
         grep {defined} ( delete $arg->{name}, delete $arg->{names} );
 
-    @names = uniq(
-        grep    {defined}
-            map { $_->nested_name } @{ $self->get_fields } ) if !@names;
+    if ( !@names ) {
+        @names = uniq
+            grep {defined}
+            map  { $_->nested_name } @{ $self->get_fields };
+    }
 
     croak "no field names to add plugin to" if !@names;
 
@@ -79,6 +82,14 @@ sub _single_plugin {
     return @return;
 }
 
+sub pre_process {
+    my ($self) = @_;
+
+    map { $_->pre_process } @{ $self->_elements };
+
+    return;
+}
+
 sub process {
     my ($self) = @_;
 
@@ -106,12 +117,13 @@ sub render_data {
 }
 
 sub render_data_non_recursive {
-    my $self = shift;
+    my ( $self, $args ) = @_;
 
     my $render = $self->next::method( {
             tag     => $self->tag,
             content => xml_escape( $self->content ),
-            @_ ? %{ $_[0] } : () } );
+            $args ? %$args : (),
+        } );
 
     return $render;
 }
@@ -133,7 +145,8 @@ sub string {
     if ( defined $render->{tag} ) {
         $html .= sprintf "<%s%s>",
             $render->{tag},
-            process_attrs( $render->{attributes} );
+            process_attrs( $render->{attributes} ),
+            ;
     }
 
     if ( defined $render->{legend} ) {
@@ -433,7 +446,7 @@ Base-class for L<HTML::FormFu::Element::Fieldset>.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
