@@ -1579,9 +1579,10 @@ sub _require_plugin {
     my $plugin = $class->new( {
             type   => $type,
             parent => $self,
-            %$arg
         } );
 
+    $plugin->populate($arg);
+
     return $plugin;
 }
 
